==> haskell-raw-strings-qq-1.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-raw-strings-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: raw-strings-qq
version: 1.1
id: raw-strings-qq-1.1-72HharMmyIlCWaL2zTAsNh
key: raw-strings-qq-1.1-72HharMmyIlCWaL2zTAsNh
license: BSD-3-Clause
copyright: (c) Mikhail Glushenkov 2013-2015
maintainer: mikhail.glushenkov@gmail.com
author: Mikhail Glushenkov
homepage: https://github.com/23Skidoo/raw-strings-qq
synopsis: Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).
    .
    See @examples/RawRegex.hs@ for a usage example.
category: Text
abi: 9e4999e35124ef514510f7cbfa5245cc
exposed: True
exposed-modules:
    Text.RawString.QQ
import-dirs: /usr/lib/ghc-8.6.5/site-local/raw-strings-qq-1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/raw-strings-qq-1.1
hs-libraries: HSraw-strings-qq-1.1-72HharMmyIlCWaL2zTAsNh
depends:
    base-4.12.0.0 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock
haddock-html: /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-raw-strings-qq-1.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-raw-strings-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: raw-strings-qq
version: 1.1
id: raw-strings-qq-1.1-FCyscPqSdS0269Bamjnfgv
key: raw-strings-qq-1.1-FCyscPqSdS0269Bamjnfgv
license: BSD-3-Clause
copyright: (c) Mikhail Glushenkov 2013-2015
maintainer: mikhail.glushenkov@gmail.com
author: Mikhail Glushenkov
homepage: https://github.com/23Skidoo/raw-strings-qq
synopsis: Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).
    .
    See @examples/RawRegex.hs@ for a usage example.
category: Text
abi: 6f46242fabeaf212ddbf5ce4ab8f6dc3
exposed: True
exposed-modules:
    Text.RawString.QQ
import-dirs: /usr/lib/ghc-8.6.5/site-local/raw-strings-qq-1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/raw-strings-qq-1.1
hs-libraries: HSraw-strings-qq-1.1-FCyscPqSdS0269Bamjnfgv
depends:
    base-4.12.0.0 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock
haddock-html: /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
